/*
 * build.h
 * Automatically generated
 */
#define BUILD_HOSTNAME "riscv64-4.ports.openbsd.org"
#define BUILD_KERNEL "7.7"
#define BUILD_MACHINE "riscv64"
#define BUILD_OS "OpenBSD"
#define BUILD_DATE "2025-04-25 13:29:04 UTC"
#define BUILD_USER "_pbuild"

