/*
 * buildopts.h
 * Automatically generated
 */

#define OPTIONAL_API 1
#define AST_BUILDOPT_SUM "35365abbc28501b3015f9b6b95e47745"
#define AST_BUILDOPTS "OPTIONAL_API "
#define AST_BUILDOPTS_ALL "OPTIONAL_API "
